@@ -65,7 +65,7 @@ exports.create = function(config) {
     global.mainWindow.webContents.on('page-favicon-updated', async function(ev, favicons) {
         if (!favicons || favicons.length <= 0 || !favicons[0].startsWith('data:')) {
             if (lastFavicon !== null) {
-                win.setIcon(defaultIcon);
+                global.mainWindow.setIcon(defaultIcon);
                 trayIcon.setImage(defaultIcon);
                 lastFavicon = null;
             }
